//=============================================================================
/** @file		ProgramWindow.hpp
 *
 * Defines the main window class.
 *
    Shader Maker - a cross-platform GLSL editor.
    Copyright (C) 2007-2008 Markus Kramer
    For details, see main.cpp or COPYING.

=============================================================================*/

#ifndef __PROGRAMWINDOW_HPP_INCLUDED__
#define __PROGRAMWINDOW_HPP_INCLUDED__

#include <QMainWindow>
#include <QTabWidget>
#include <QTextEdit>

// forward declarations
class IShader;
class IScene;
class CLightWidget;
class CMaterialWidget;
class CUniformWidget;
class CSceneWidget;
class CTextureWidget;
class CGLWidget;
class CEditor;

class CProgramWindow : public QMainWindow
{
    Q_OBJECT

public:
    explicit CProgramWindow(QWidget *parent = 0);
    ~CProgramWindow();

    /**
     * Initializes the object.
     * It creates and shows the widgets etc.
     * @return Wether initalization succeeded.
     */
    bool init();

    /**
     * Cleans up the object and prepares for object destruction.
     */
    void shutdown();

private slots:
    void render();
    void linkProgram();
    void deactivateProgram();
    void aboutToQuit();

private:
    CGLWidget*  m_glWidget;
    QTabWidget* m_tabs;
    QTextEdit*  m_logging;
    QTextEdit*  m_driverInfoWidget;

    // widgets
    CSceneWidget*       m_sceneWidget;
    CLightWidget*       m_lighting;
    CMaterialWidget*    m_material;
    CUniformWidget*     m_uniform;
    CTextureWidget*     m_texture;

    // components
    CEditor*    m_editor;
    IScene*     m_scene;

    // QWidget
    void closeEvent( QCloseEvent* event ) override;

    // create main widgets
    // -> create order == tab order
    void createLogWidget();
    void createSceneWidget();
    void createLightWidget();
    void createUniformWidget();
    void createTextureWidget();
    void createDriverInfoWidget();

    // setup other widgets
    void createGlWidget();
    void createLayout();
};

#endif // __PROGRAMWINDOW_HPP_INCLUDED__
